==> yndenz-modules-reviews-4.2.4-aa89b9.zip: changelog.md <==
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [4.2.4] - 2019-09-18
### Fixed
- First review is not included when all reviews are fetched

## [4.2.3] - 2019-05-20
### Fixed
- Aggregate rating not set correctly

## [4.2.2] - 2019-05-20
### Fixed
- Use correct Yoast SEO filter

## [4.2.1] - 2019-05-20
### Changed
- Use Yoast SEO schema filters to add aggregate rating to JSON+LD when version above 11.0

## [4.2.0] - 2019-03-18
### Changed
- Use JSON+LD instead of microformats

## [4.1.0] - 2018-10-12
### Changed
- Upgrade Advanced Custom Fields dependency

## [4.0.1] - 2018-10-05
### Changed
- Use post type archive link for read more button per default

## [4.0.0] - 2018-10-05
### Changed
- Code style set to WordPress standards
- Register post type through new base module feature
- Field group ids should always start with group_
- Replace support for Bootstrap with Pure CSS

## [3.1.2] - 2018-09-17
### Changed
- Compatible with multiple version of base-module

## [3.1.1] - 2018-09-06
### Fixed
- Translation context for breadcrumb

## [3.1.0] - 2018-08-30
### Added
- Context in string translation

## [3.0.0] - 2018-08-16
### Changed
- Advanced Custom Fields keys should always start with field_

## [2.1.2] - 2018-08-15
### Added
- Changelog file

[Unreleased]: https://gitlab.yndenz.com/yndenz-modules/reviews/compare/4.2.4...HEAD
[4.2.4]: https://gitlab.yndenz.com/yndenz-modules/reviews/compare/4.2.3...4.2.4
[4.2.3]: https://gitlab.yndenz.com/yndenz-modules/reviews/compare/4.2.2...4.2.3
[4.2.2]: https://gitlab.yndenz.com/yndenz-modules/reviews/compare/4.2.1...4.2.2
[4.2.1]: https://gitlab.yndenz.com/yndenz-modules/reviews/compare/4.2.0...4.2.1
[4.2.0]: https://gitlab.yndenz.com/yndenz-modules/reviews/compare/4.1.0...4.2.0
[4.1.0]: https://gitlab.yndenz.com/yndenz-modules/reviews/compare/4.0.1...4.1.0
[4.0.1]: https://gitlab.yndenz.com/yndenz-modules/reviews/compare/4.0.0...4.0.1
[4.0.0]: https://gitlab.yndenz.com/yndenz-modules/reviews/compare/3.1.2...4.0.0
[3.1.2]: https://gitlab.yndenz.com/yndenz-modules/reviews/compare/3.1.1...3.1.2
[3.1.1]: https://gitlab.yndenz.com/yndenz-modules/reviews/compare/3.1.0...3.1.1
[3.1.0]: https://gitlab.yndenz.com/yndenz-modules/reviews/compare/3.0.0...3.1.0
[3.0.0]: https://gitlab.yndenz.com/yndenz-modules/reviews/compare/2.1.2...3.0.0
[2.1.2]: https://gitlab.yndenz.com/yndenz-modules/reviews/compare/2.1.1...2.1.2

==> yndenz-modules-reviews-4.3.0-0109a7.zip: changelog.md <==
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [4.3.0] - 2019-10-04
### Changed
- Remove microformats as they're already in json+ld

## [4.2.4] - 2019-09-18
### Fixed
- First review is not included when all reviews are fetched

## [4.2.3] - 2019-05-20
### Fixed
- Aggregate rating not set correctly

## [4.2.2] - 2019-05-20
### Fixed
- Use correct Yoast SEO filter

## [4.2.1] - 2019-05-20
### Changed
- Use Yoast SEO schema filters to add aggregate rating to JSON+LD when version above 11.0

## [4.2.0] - 2019-03-18
### Changed
- Use JSON+LD instead of microformats

## [4.1.0] - 2018-10-12
### Changed
- Upgrade Advanced Custom Fields dependency

## [4.0.1] - 2018-10-05
### Changed
- Use post type archive link for read more button per default

## [4.0.0] - 2018-10-05
### Changed
- Code style set to WordPress standards
- Register post type through new base module feature
- Field group ids should always start with group_
- Replace support for Bootstrap with Pure CSS

## [3.1.2] - 2018-09-17
### Changed
- Compatible with multiple version of base-module

## [3.1.1] - 2018-09-06
### Fixed
- Translation context for breadcrumb

## [3.1.0] - 2018-08-30
### Added
- Context in string translation

## [3.0.0] - 2018-08-16
### Changed
- Advanced Custom Fields keys should always start with field_

## [2.1.2] - 2018-08-15
### Added
- Changelog file

[Unreleased]: https://gitlab.yndenz.com/yndenz-modules/reviews/compare/4.3.0...HEAD
[4.3.0]: https://gitlab.yndenz.com/yndenz-modules/reviews/compare/4.2.4...4.3.0
[4.2.4]: https://gitlab.yndenz.com/yndenz-modules/reviews/compare/4.2.3...4.2.4
[4.2.3]: https://gitlab.yndenz.com/yndenz-modules/reviews/compare/4.2.2...4.2.3
[4.2.2]: https://gitlab.yndenz.com/yndenz-modules/reviews/compare/4.2.1...4.2.2
[4.2.1]: https://gitlab.yndenz.com/yndenz-modules/reviews/compare/4.2.0...4.2.1
[4.2.0]: https://gitlab.yndenz.com/yndenz-modules/reviews/compare/4.1.0...4.2.0
[4.1.0]: https://gitlab.yndenz.com/yndenz-modules/reviews/compare/4.0.1...4.1.0
[4.0.1]: https://gitlab.yndenz.com/yndenz-modules/reviews/compare/4.0.0...4.0.1
[4.0.0]: https://gitlab.yndenz.com/yndenz-modules/reviews/compare/3.1.2...4.0.0
[3.1.2]: https://gitlab.yndenz.com/yndenz-modules/reviews/compare/3.1.1...3.1.2
[3.1.1]: https://gitlab.yndenz.com/yndenz-modules/reviews/compare/3.1.0...3.1.1
[3.1.0]: https://gitlab.yndenz.com/yndenz-modules/reviews/compare/3.0.0...3.1.0
[3.0.0]: https://gitlab.yndenz.com/yndenz-modules/reviews/compare/2.1.2...3.0.0
[2.1.2]: https://gitlab.yndenz.com/yndenz-modules/reviews/compare/2.1.1...2.1.2
